0.1.17 - Fixed alternating words syntax [cat|dog] - pipes are only reserved inside variants. Also standardised MagicPrompt, AttentionGenerator, and FeelinLucky to use a DummyGenerator by default so that users are not forced to provide an alternative generator if one isn't needed.
0.1.16 - Changed type annotations to use classes from the typing package instead of native type in order to support python 3.7
0.1.15 - First public release